##  Overview
The Digital Operational Resilience Act (DORA) is an EU regulation designed to ensure that financial institutions can effectively manage technology risks and remain resilient to disruptions in their information and communication technology (ICT) systems. DORA aims to enhance financial institutions' operational resilience by setting uniform guidelines for managing ICT risks, incident reporting, operational resilience testing, and third-party risk management.
With SAP LeanIX’s meta model extension, organizations can seamlessly integrate DORA regulatory requirements with enterprise architecture. You can create a regulatory dictionary, categorize DORA requirements, and link DORA obligations directly to specific IT and business architecture elements, making it easy to track and manage compliance. You can document scenario testing for resilience assessments, document the impacts, and evaluate vendor compliance. Additionally, during global incidents, you can conduct real-time impact assessment, ensuring that you can quickly respond to disruptions.
For a detailed guide on all available attributes with DORA extension, see[Digital Operational Resilience Act (DORA) Attributes](https://help.sap.com/docs/leanix/ea/digital-operational-resilience-act-dora-attributes?locale=en-US&state=PRODUCTION&version=CLOUD "Learn which attributes are available with the Digital Operational Resilience Act \(DORA\) extension.").
